==> vtigercrm-5.3.0p0.tgz: modules/Products/language/pt_br.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese|30/12/2010|Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/
$mod_strings = Array(
'LBL_MODULE_NAME'=>'Produtos',
'SINGLE_Products'=>'Produto',
'LBL_LIST_PRODUCT_NAME'=>'Nome Produto',
'LBL_TOOL_FORM_TITLE'=>'Ferramentas Produto',
'LBL_SEARCH_FORM_TITLE'=>'Pesquisa Produto',
'LBL_PRODUCT_NAME'=>'Nome Produto:',
'LBL_VENDOR_NAME'=>'Nome Fornecedor:',
'LBL_PRICEBOOK_NAME'=>'Nome Lista Preço:',
'LBL_VENDOR'=>'Fornecedor',
'LBL_PRICEBOOK'=>'Lista Preço',
'LBL_VENDOR_INFORMATION'=>'Dados do Fornecedor:',
'LBL_PRICEBOOK_INFORMATION'=>'Dados da Lista de Preços:',
'LBL_VENDOR_ADDRESS_INFORMATION'=>'Dados do Endereço:',
'LBL_DESCRIPTION_INFORMATION'=>'Descrição',
'LBL_PRICING_INFORMATION'=>'Informação de Preços:',
'LBL_STOCK_INFORMATION'=>'Informação do Estoque:',
'LBL_LIST_FORM_TITLE'=>'Lista de Produtos',
'LBL_LIST_VENDOR_FORM_TITLE'=>'Lista de Fonecedores',
'LBL_LIST_PRICEBOOK_FORM_TITLE'=>'Lista de Lista Preço',
'LBL_LIST_CATEGORY'=>'Categoria Produto',
'LBL_CATEGORY'=>'Categoria Produto:',
'LBL_PRODUCT_CODE'=>'Código Produto',
'LBL_LIST_PRODUCT_CODE'=>'Código Produto:',
'LBL_PRODUCT_ACTIVE'=>'Produto Ativo',
'LBL_PRODUCT_COMMISSION_RATE'=>'Comissão (%)',
'LBL_PRODUCT_QTY_PER_UNIT'=>'Qde/Un',
'LBL_PRODUCT_UNIT_PRICE'=>'Preço Unitário',
'LBL_PB_LIST_PRICE'=>'Lista de Preços',
'LBL_PRODUCT_DESCRIPTION'=>'Descrição',
'LBL_PRODUCT_IMAGE'=>'Imagem',
'LBL_NEW_FORM_TITLE'=>'Novo Produto',
'LBL_PRODUCT_INFORMATION'=>'Dados do Produto',
'LBL_CUSTOM_INFORMATION'=>'Informação Customizada',
'LBL_DESCRIPTION_INFORMATION'=>'Descrição',

//New entry
'LBL_UPLOAD'=>'Transferir Arquivo',

'LBL_PRODUCT'=>'Produto',
'LBL_NEW_PRODUCT'=>'Novo Produto',
'LBL_COLON'=>':',

'LBL_ATTACHMENTS'=>'Anexos',
'LBL_ATTACH_FILE'=>'Anexar Arquivo',
'LBL_DESCRIPTION'=>'Descrição',
'LBL_FILE'=>'Nome Arquivo',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nova Oportunidade',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TICKET'=>'Novo Ticket',
'LBL_TICKET_TITLE'=>'Tickets',

'LBL_NEW_CALL'=>'Nova Chamada',
'LBL_CALL_TITLE'=>'Chamadas',

'LBL_NEW_MEETING'=>'Nova Reunião',
'LBL_MEETING_TITLE'=>'Reuniões',

'LBL_NEW_ATTACHMENT'=>'Novo Anexo',
'LBL_ATTACHMENT_TITLE'=>'Anexos',

//Added vtiger_fields after RC1 - Release
'LBL_MANUFACTURER'=>'Fabricante',
'LBL_PRODUCTCATEGORY'=>'Categoria Produto',
'LBL_SUPPORT_START_DATE'=>'Data Início Suporte',
'LBL_SUPPORT_EXPIRY_DATE'=>'Data Expira Suporte',
'LBL_PURCHASE_DATE'=>'Data Compra',

//Added for 4GA
'Product Name'=>'Nome Produto',
//'Product Code'=>'Part Number',
'Part Number'=>'Part Number',
'Product Active'=>'Produto Ativo',
'Commission Rate'=>'Comissão(%)',
'Qty/Unit'=>'Qde/Un',
'Unit Price'=>'Preço Unitário',
'Manufacturer'=>'Fabricante',
'Product Category'=>'Categoria de Produto',
'Support Start Date'=>'Data Início Suporte',
'Support Expiry Date'=>'Data em que Expira o Suporte',
'Purchase Date'=>'Data Compra',
'Sales Start Date'=>'Data Início Vendas',
'Sales End Date'=>'Data Final Vendas',
'Created Time'=>'Data Criação',
'Modified Time'=>'Data Modificação',
'Related To'=>'Relacionado à',
'Usage Unit'=>'Unidade Utilizada',
'Handler'=>'Responsável',
'Contact Name'=>'Nome Contato',
'Currency'=>'Moeda',
'Reorder Level'=>'Nível Reabastecimento',
'Tax Class'=>'Categoria de Impostos',
'Mfr PartNo'=>'Cód. Fabricante',
'Vendor PartNo'=>'Cód. Fornecedor',
'Serial No'=>'No. Série',
'Qty In Stock'=>'Qde. em Estoque',
'Product Sheet'=>'Ficha do Produto',
'Qty In Demand'=>'Qde. Comprada',
'GL Account'=>'Conta Plano Contas',
'Vendor Name'=>'Nome Fornecedor',

//Mapping for Name
'Name'=>'Nome',
'Company Name'=>'Nome Empresa',
'Phone'=>'Fone',
'Email'=>'E-mail',
'Website'=>'Website',
'GL Account'=>'Conta Plano Contas',
'Category'=>'Categoria',
'Street'=>'Rua',
'City'=>'Cidade',
'State'=>'Estado',
'Postal Code'=>'CEP',
'Country'=>'País',
'Description'=>'Descrição',
'Po Box'=>'Cx Postal',

//Mapping for price book
'Price Book Name'=>'Nome Lista Preço',
'Product Name'=>'Nome Produto',
'Active'=>'Ativo',

//Added for 4.2 Release -- CustomView
'LBL_ALL'=>'Todos',
'LBL_VENDOR_SEARCH_FORM_TITLE'=>'Pesquisar Fornecedor',
'LBL_PRICEBOOK_SEARCH_FORM_TITLE'=>'Pesquisar Lista Preços',
'LBL_VENDOR_TITLE'=>'Fornecedores',
'LBL_PRICEBOOK_TITLE'=>'Lista de Preços',
'LBL_PRODUCTS_TITLE'=>'Produtos',
'LBL_COMPANY_NAME'=>'Nome Empresa',
'LBL_CATEGORY_TITLE'=>'Categoria',
'LBL_ACTIVE_TITLE'=>'Ativo',
'LBL_LIST_VENDOR_NAME'=>'Nome Fornecedor',
'LBL_IMAGE_INFORMATION'=>'Informação Imagem Produto:',
'Product Image'=>'Imagem Produto',
'LBL_ADD_PRICEBOOK_BUTTON_TITLE'=>'Adicionar à Lista de Preços [Alt+B]',
'LBL_ADD_PRICEBOOK_BUTTON_KEY'=>'B',
'LBL_ADD_PRICEBOOK_BUTTON_LABEL'=>'Adicionar à Lista de Preços',
'LBL_ADD_PRODUCT_PRICEBOOKS'=>'Adicionar Produto na Lista de Preços',
'LBL_ADD_PRODUCTS_PRICEBOOK'=>'Adicionar Produtos na Lista de Preços',

//Added for 4.2 patch2 release
'LBL_MAXIMUM_LIMIT_ERROR'=>'Desculpe, os arquivos transferidos excederam o limite máximo vtiger_filesize. Por favor, tente um arquivo menor que 800000 bytes',
'LBL_UPLOAD_ERROR'=>'Problemas na transferência do arquivo. Por favor tente novamente!',
'LBL_IMAGE_ERROR'=>'O arquivo não é do tipo imagem(.gif/.jpg/.png)',
'LBL_INVALID_IMAGE'=>'Arquivo inválido ou vazio',
'LBL_EMAIL'=>'Email',
'Product'=>'Produto',
'LBL_EDITLISTPRICE'=>'Editar Lista Preço',

//Added for existing picklist entries

'--None--'=>'--Nada--',

'Hardware'=>'Hardware',
'Software'=>'Software',
'CRM Applications'=>'Aplicações CRM',

'300-Sales-Software'=>'300-Vendas-Software',
'301-Sales-Hardware'=>'301-Vendas-Hardware',
'302-Rental-Income'=>'302-Aluguel-Renda',
'303-Interest-Income'=>'303-Juros-Renda',
'304-Sales-Software-Support'=>'304-Vendas-Suporte-Software',
'305-Sales Other'=>'305-Outras Vendas',
'306-Internet Sales'=>'306-Vendas Internet',
'307-Service-Hardware Labor'=>'307-Serviço-Lab. Hardware',
'308-Sales-Books'=>'308-Vendas-Livros',

'Box'=>'Cx',
'Carton'=>'Cartão',
'Caton'=>'',
'Dozen'=>'Dz',
'Each'=>'Cada',
'Hours'=>'Hora',
'Impressions'=>'Impressão',
'Lb'=>'Lb',
'M'=>'M',
'Pack'=>'Pct',
'Pages'=>'Páginas',
'Pieces'=>'Peças',
'Quantity'=>'Quantidade',
'Reams'=>'Resma',
'Sheet'=>'Folhas',
'Spiral Binder'=>'',
'Sq Ft'=>'',

//Added for 5.0.3
'MSG_STOCK_LEVEL'=>'O Nível de Estoque está baixo',
'MSG_DEAR'=>'Caro',
'MSG_CURRENT_STOCK'=>'O estoque atual de',
'MSG_IN_OUR_WAREHOUSE'=>'em nosso Almoxarifado é',
'MSG_PROCURE_REQUIRED_NUMBER'=>'Por gentileza, obtenha o número requerido de unidades para que o nível de estoque volte ao normal',
'MSG_SEVERITY'=>'Gravidade: Elevada',
'MSG_THANKS'=>'Obrigado,',

// Added after 5.0.4 GA

'LBL_PRODUCT_PRICES'=>'Preços Produtos',
'Member Of'=>'Membro de',

// Module Sequence Numbering
'Product No' => 'Cod. Produto',
// END

'LBL_NO_TAXES_ASSOCIATED'=>'Nenhum Imposto associado a este Produto',
);

?>

==> vtigercrm-5.4.0.tgz: modules/Products/language/pt_br.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/
$mod_strings = Array(
'LBL_MODULE_NAME'=>'Produtos',
'SINGLE_Products'=>'Produto',
'LBL_LIST_PRODUCT_NAME'=>'Nome Produto',
'LBL_TOOL_FORM_TITLE'=>'Ferramentas Produto',
'LBL_SEARCH_FORM_TITLE'=>'Pesquisa Produto',
'LBL_PRODUCT_NAME'=>'Nome Produto:',
'LBL_VENDOR_NAME'=>'Nome Fornecedor:',
'LBL_PRICEBOOK_NAME'=>'Nome Lista Preço:',
'LBL_VENDOR'=>'Fornecedor',
'LBL_PRICEBOOK'=>'Lista Preço',
'LBL_VENDOR_INFORMATION'=>'Dados do Fornecedor:',
'LBL_PRICEBOOK_INFORMATION'=>'Dados da Lista de Preços:',
'LBL_VENDOR_ADDRESS_INFORMATION'=>'Dados do Endereço:',
'LBL_DESCRIPTION_INFORMATION'=>'Descrição',
'LBL_PRICING_INFORMATION'=>'Informação de Preços:',
'LBL_STOCK_INFORMATION'=>'Informação do Estoque:',
'LBL_LIST_FORM_TITLE'=>'Lista de Produtos',
'LBL_LIST_VENDOR_FORM_TITLE'=>'Lista de Fonecedores',
'LBL_LIST_PRICEBOOK_FORM_TITLE'=>'Lista de Lista Preço',
'LBL_LIST_CATEGORY'=>'Categoria Produto',
'LBL_CATEGORY'=>'Categoria Produto:',
'LBL_PRODUCT_CODE'=>'Código Produto',
'LBL_LIST_PRODUCT_CODE'=>'Código Produto:',
'LBL_PRODUCT_ACTIVE'=>'Produto Ativo',
'LBL_PRODUCT_COMMISSION_RATE'=>'Comissão (%)',
'LBL_PRODUCT_QTY_PER_UNIT'=>'Qde/Un',
'LBL_PRODUCT_UNIT_PRICE'=>'Preço Unitário',
'LBL_PB_LIST_PRICE'=>'Lista de Preços',
'LBL_PRODUCT_DESCRIPTION'=>'Descrição',
'LBL_PRODUCT_IMAGE'=>'Imagem',
'LBL_NEW_FORM_TITLE'=>'Novo Produto',
'LBL_PRODUCT_INFORMATION'=>'Dados do Produto',
'LBL_CUSTOM_INFORMATION'=>'Informação Customizada',
'LBL_DESCRIPTION_INFORMATION'=>'Descrição',

//New entry
'LBL_UPLOAD'=>'Transferir Arquivo',

'LBL_PRODUCT'=>'Produto',
'LBL_NEW_PRODUCT'=>'Novo Produto',
'LBL_COLON'=>':',

'LBL_ATTACHMENTS'=>'Anexos',
'LBL_ATTACH_FILE'=>'Anexar Arquivo',
'LBL_DESCRIPTION'=>'Descrição',
'LBL_FILE'=>'Nome Arquivo',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nova Oportunidade',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TICKET'=>'Novo Ticket',
'LBL_TICKET_TITLE'=>'Tickets',

'LBL_NEW_CALL'=>'Nova Chamada',
'LBL_CALL_TITLE'=>'Chamadas',

'LBL_NEW_MEETING'=>'Nova Reunião',
'LBL_MEETING_TITLE'=>'Reuniões',

'LBL_NEW_ATTACHMENT'=>'Novo Anexo',
'LBL_ATTACHMENT_TITLE'=>'Anexos',

//Added vtiger_fields after RC1 - Release
'LBL_MANUFACTURER'=>'Fabricante',
'LBL_PRODUCTCATEGORY'=>'Categoria Produto',
'LBL_SUPPORT_START_DATE'=>'Data Início Suporte',
'LBL_SUPPORT_EXPIRY_DATE'=>'Data Expira Suporte',
'LBL_PURCHASE_DATE'=>'Data Compra',

//Added for 4GA
'Product Name'=>'Nome Produto',
//'Product Code'=>'Part Number',
'Part Number'=>'Part Number',
'Product Active'=>'Produto Ativo',
'Commission Rate'=>'Comissão(%)',
'Qty/Unit'=>'Qde/Un',
'Unit Price'=>'Preço Unitário',
'Manufacturer'=>'Fabricante',
'Product Category'=>'Categoria de Produto',
'Support Start Date'=>'Data Início Suporte',
'Support Expiry Date'=>'Data em que Expira o Suporte',
'Purchase Date'=>'Data Compra',
'Sales Start Date'=>'Data Início Vendas',
'Sales End Date'=>'Data Final Vendas',
'Created Time'=>'Data Criação',
'Modified Time'=>'Data Modificação',
'Related To'=>'Relacionado à',
'Usage Unit'=>'Unidade Utilizada',
'Handler'=>'Responsável',
'Contact Name'=>'Nome Contato',
'Currency'=>'Moeda',
'Reorder Level'=>'Nível Reabastecimento',
'Tax Class'=>'Categoria de Impostos',
'Mfr PartNo'=>'Cód. Fabricante',
'Vendor PartNo'=>'Cód. Fornecedor',
'Serial No'=>'No. Série',
'Qty In Stock'=>'Qde. em Estoque',
'Product Sheet'=>'Ficha do Produto',
'Qty In Demand'=>'Qde. Comprada',
'GL Account'=>'Conta Plano Contas',
'Vendor Name'=>'Nome Fornecedor',

//Mapping for Name
'Name'=>'Nome',
'Company Name'=>'Nome Empresa',
'Phone'=>'Fone',
'Email'=>'E-mail',
'Website'=>'Website',
'GL Account'=>'Conta Plano Contas',
'Category'=>'Categoria',
'Street'=>'Rua',
'City'=>'Cidade',
'State'=>'Estado',
'Postal Code'=>'CEP',
'Country'=>'País',
'Description'=>'Descrição',
'Po Box'=>'Cx Postal',

//Mapping for price book
'Price Book Name'=>'Nome Lista Preço',
'Product Name'=>'Nome Produto',
'Active'=>'Ativo',

//Added for 4.2 Release -- CustomView
'LBL_ALL'=>'Todos',
'LBL_VENDOR_SEARCH_FORM_TITLE'=>'Pesquisar Fornecedor',
'LBL_PRICEBOOK_SEARCH_FORM_TITLE'=>'Pesquisar Lista Preços',
'LBL_VENDOR_TITLE'=>'Fornecedores',
'LBL_PRICEBOOK_TITLE'=>'Lista de Preços',
'LBL_PRODUCTS_TITLE'=>'Produtos',
'LBL_COMPANY_NAME'=>'Nome Empresa',
'LBL_CATEGORY_TITLE'=>'Categoria',
'LBL_ACTIVE_TITLE'=>'Ativo',
'LBL_LIST_VENDOR_NAME'=>'Nome Fornecedor',
'LBL_IMAGE_INFORMATION'=>'Informação Imagem Produto:',
'Product Image'=>'Imagem Produto',
'LBL_ADD_PRICEBOOK_BUTTON_TITLE'=>'Adicionar à Lista de Preços [Alt+B]',
'LBL_ADD_PRICEBOOK_BUTTON_KEY'=>'B',
'LBL_ADD_PRICEBOOK_BUTTON_LABEL'=>'Adicionar à Lista de Preços',
'LBL_ADD_PRODUCT_PRICEBOOKS'=>'Adicionar Produto na Lista de Preços',
'LBL_ADD_PRODUCTS_PRICEBOOK'=>'Adicionar Produtos na Lista de Preços',

//Added for 4.2 patch2 release
'LBL_MAXIMUM_LIMIT_ERROR'=>'Desculpe, os arquivos transferidos excederam o limite máximo vtiger_filesize. Por favor, tente um arquivo menor que 800000 bytes',
'LBL_UPLOAD_ERROR'=>'Problemas na transferência do arquivo. Por favor tente novamente!',
'LBL_IMAGE_ERROR'=>'O arquivo não é do tipo imagem(.gif/.jpg/.png)',
'LBL_INVALID_IMAGE'=>'Arquivo inválido ou vazio',
'LBL_EMAIL'=>'Email',
'Product'=>'Produto',
'LBL_EDITLISTPRICE'=>'Editar Lista Preço',

//Added for existing picklist entries

'--None--'=>'--Nada--',

'Hardware'=>'Hardware',
'Software'=>'Software',
'CRM Applications'=>'Aplicações CRM',

'300-Sales-Software'=>'300-Vendas-Software',
'301-Sales-Hardware'=>'301-Vendas-Hardware',
'302-Rental-Income'=>'302-Aluguel-Renda',
'303-Interest-Income'=>'303-Juros-Renda',
'304-Sales-Software-Support'=>'304-Vendas-Suporte-Software',
'305-Sales Other'=>'305-Outras Vendas',
'306-Internet Sales'=>'306-Vendas Internet',
'307-Service-Hardware Labor'=>'307-Serviço-Lab. Hardware',
'308-Sales-Books'=>'308-Vendas-Livros',

'Box'=>'Cx',
'Carton'=>'Cartão',
'Caton'=>'',
'Dozen'=>'Dz',
'Each'=>'Cada',
'Hours'=>'Hora',
'Impressions'=>'Impressão',
'Lb'=>'Lb',
'M'=>'M',
'Pack'=>'Pct',
'Pages'=>'Páginas',
'Pieces'=>'Peças',
'Quantity'=>'Quantidade',
'Reams'=>'Resma',
'Sheet'=>'Folhas',
'Spiral Binder'=>'',
'Sq Ft'=>'', // Square Foot = Pé quadrado

//Added for 5.0.3
'MSG_STOCK_LEVEL'=>'O Nível de Estoque está baixo',
'MSG_DEAR'=>'Caro',
'MSG_CURRENT_STOCK'=>'O estoque atual de',
'MSG_IN_OUR_WAREHOUSE'=>'em nosso Almoxarifado é',
'MSG_PROCURE_REQUIRED_NUMBER'=>'Por gentileza, obtenha o número requerido de unidades para que o nível de estoque volte ao normal',
'MSG_SEVERITY'=>'Gravidade: Elevada',
'MSG_THANKS'=>'Obrigado,',

// Added after 5.0.4 GA

'LBL_PRODUCT_PRICES'=>'Preços Produtos',
'Member Of'=>'Membro de',

// Module Sequence Numbering
'Product No' => 'Cod. Produto',
// END

'LBL_NO_TAXES_ASSOCIATED'=>'Nenhum Imposto associado a este Produto',
'Parent Product' => 'Produto Pai',

'Products ID' => 'ID Produtos',
);

?>
